@@ -33,5 +33,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <giblib/gib_queue.h>
 #include <giblib/gib_stack.h>
 #include <giblib/gib_style.h>
+#include <giblib/gib_utils.h>
+#include <giblib/gib_debug.h>
 
 #endif
